@@ -7,7 +7,7 @@ use vars qw($VERSION @EXPORT @EXPORT_OK);
 use base 'Exporter';
 @EXPORT_OK = @EXPORT = qw( hash2xml xml2hash );
 
-$VERSION = '0.36';
+$VERSION = '0.37';
 
 require XSLoader;
 XSLoader::load('XML::Hash::XS', $VERSION);
@@ -224,6 +224,14 @@ if defined that the key name for the text content(used only if use_attr=1).
 
 This option is similar to "ForceArray" from XMl::Simple module: L<https://metacpan.org/pod/XML::Simple#ForceArray-1-in---important>.
 
+=item force_content => [ = 0 ] I<# xml2hash>
+
+This option is similar to "ForceContent" from XMl::Simple module: L<https://metacpan.org/pod/XML::Simple#ForceContent-1-in---seldom-used>.
+
+=item merge_text [ = 0 ] I<# xml2hash>
+
+Setting this option to "1" will cause merge adjacent test nodes.
+
 =item xml_decl [ = 1 ] I<# hash2xml>
 
 if xml_decl is "1", output will start with the XML declaration '<?xml version="1.0" encoding="utf-8"?>'.
